==> testdisk_6.4.1.orig.tar.gz: testdisk-6.4.1/src/file_qxd.c <==
/*

    File: file_qxd.c

    Copyright (C) 2006 Christophe GRENIER <grenier@cgsecurity.org>
  
    This software is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
  
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
  
    You should have received a copy of the GNU General Public License along
    with this program; if not, write the Free Software Foundation, Inc., 59
    Temple Place - Suite 330, Boston MA 02111-1307, USA.

 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif
#ifdef HAVE_STRING_H
#include <string.h>
#endif
#include "types.h"
#include "photorec.h"

static const char* header_check_qxd(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only,  t_file_recovery *file_recovery);
const t_file_hint file_hint_qxd= {
  .extension="qxd",
  .description="QuarkXpress Document",
  .min_header_distance=0,
  .min_filesize=0,
  .max_filesize=PHOTOREC_MAX_FILE_SIZE,
  .recover=1,
  .header_check=&header_check_qxd,
  .data_check=NULL,
  .file_check=NULL
};

static const char* header_check_qxd(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only,  t_file_recovery *file_recovery)
{
  const unsigned char qxd_header[4]={'X','P','R','3' };
  if(memcmp(buffer,qxd_header,sizeof(qxd_header))==0)
    return file_hint_qxd.extension;
  /* Intel or Mac QuarkXpress Document */
  if(memcmp(&buffer[2],"IIXPR3",6)==0 || memcmp(&buffer[2],"MMXPR3",6)==0)
    return "qxp";
  return NULL;
}

==> testdisk_6.6.orig.tar.gz: testdisk-6.6.orig/src/file_qxd.c <==
/*

    File: file_qxd.c

    Copyright (C) 2006 Christophe GRENIER <grenier@cgsecurity.org>
  
    This software is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
  
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
  
    You should have received a copy of the GNU General Public License along
    with this program; if not, write the Free Software Foundation, Inc., 51
    Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif
#ifdef HAVE_STRING_H
#include <string.h>
#endif
#include <stdio.h>
#include "types.h"
#include "photorec.h"

static const char* header_check_qxd(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only,  t_file_recovery *file_recovery);
const t_file_hint file_hint_qxd= {
  .extension="qxd",
  .description="QuarkXpress Document",
  .min_header_distance=0,
  .min_filesize=0,
  .max_filesize=PHOTOREC_MAX_FILE_SIZE,
  .recover=1,
  .header_check=&header_check_qxd,
  .data_check=NULL,
  .file_check=NULL
};

static const char* header_check_qxd(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only,  t_file_recovery *file_recovery)
{
  const unsigned char qxd_header[4]={'X','P','R','3' };
  if(memcmp(buffer,qxd_header,sizeof(qxd_header))==0)
    return file_hint_qxd.extension;
  /* Intel or Mac QuarkXpress Document */
  if(memcmp(&buffer[2],"IIXPR3",6)==0 || memcmp(&buffer[2],"MMXPR3",6)==0)
    return "qxp";
  return NULL;
}
